@@ -35,7 +35,8 @@ GWEN_INHERIT(GWEN_GUI, GTK2_GUI)
 
 
 
-GWEN_GUI *Gtk2_Gui_new() {
+GWEN_GUI *Gtk2_Gui_new()
+{
   GWEN_GUI *gui;
   GTK2_GUI *xgui;
 
@@ -56,10 +57,11 @@ GWEN_GUI *Gtk2_Gui_new() {
 
 
 
-GWENHYWFAR_CB void Gtk2_Gui_FreeData(void *bp, void *p) {
+GWENHYWFAR_CB void Gtk2_Gui_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   GTK2_GUI *xgui;
 
-  xgui=(GTK2_GUI*) p;
+  xgui=(GTK2_GUI *) p;
 
   GWEN_FREE_OBJECT(xgui);
 }
@@ -67,10 +69,12 @@ GWENHYWFAR_CB void Gtk2_Gui_FreeData(void *bp, void *p) {
 
 
 GWENHYWFAR_CB int GTK2_Gui_ExecDialog(GWEN_GUI *gui,
-			GWEN_DIALOG *dlg,
-			uint32_t guiid) {
+                                      GWEN_DIALOG *dlg,
+                                      uint32_t guiid)
+{
   int rv;
 
+  assert(dlg);
   rv=GTK2_Gui_OpenDialog(gui, dlg, guiid);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -89,12 +93,14 @@ GWENHYWFAR_CB int GTK2_Gui_ExecDialog(GWEN_GUI *gui,
 
 
 
-GWENHYWFAR_CB int GTK2_Gui_OpenDialog(GWEN_GUI *gui,
-			GWEN_DIALOG *dlg,
-			uint32_t guiid) {
+GWENHYWFAR_CB int GTK2_Gui_OpenDialog(GWEN_UNUSED GWEN_GUI *gui,
+                                      GWEN_DIALOG *dlg,
+                                      GWEN_UNUSED uint32_t guiid)
+{
   int rv;
   GtkWidget *g;
 
+  assert(dlg);
   Gtk2Gui_Dialog_Extend(dlg);
   rv=Gtk2Gui_Dialog_Setup(dlg, NULL);
   if (rv<0) {
@@ -125,10 +131,12 @@ GWENHYWFAR_CB int GTK2_Gui_OpenDialog(GWEN_GUI *gui,
 
 
 
-GWENHYWFAR_CB int GTK2_Gui_CloseDialog(GWEN_GUI *gui, GWEN_DIALOG *dlg) {
+GWENHYWFAR_CB int GTK2_Gui_CloseDialog(GWEN_UNUSED GWEN_GUI *gui, GWEN_DIALOG *dlg)
+{
   GtkWidget *g;
   int rv;
 
+  assert(dlg);
   g=Gtk2Gui_Dialog_GetMainWidget(dlg);
   if (g==NULL) {
     DBG_ERROR(GWEN_LOGDOMAIN, "No main widget");
@@ -153,9 +161,11 @@ GWENHYWFAR_CB int GTK2_Gui_CloseDialog(GWEN_GUI *gui, GWEN_DIALOG *dlg) {
 
 
 
-GWENHYWFAR_CB int GTK2_Gui_RunDialog(GWEN_GUI *gui, GWEN_DIALOG *dlg, int untilEnd) {
+GWENHYWFAR_CB int GTK2_Gui_RunDialog(GWEN_UNUSED GWEN_GUI *gui, GWEN_DIALOG *dlg, int untilEnd)
+{
   int rv;
 
+  assert(dlg);
   rv=GTK2_Gui_Dialog_Run(dlg, untilEnd);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -166,13 +176,14 @@ GWENHYWFAR_CB int GTK2_Gui_RunDialog(GWEN_GUI *gui, GWEN_DIALOG *dlg, int untilE
 
 
 
-GWENHYWFAR_CB int GTK2_Gui_GetFileName(GWEN_GUI *gui,
-			 const char *caption,
-			 GWEN_GUI_FILENAME_TYPE fnt,
-			 uint32_t flags,
-			 const char *patterns,
-			 GWEN_BUFFER *pathBuffer,
-			 uint32_t guiid) {
+GWENHYWFAR_CB int GTK2_Gui_GetFileName(GWEN_UNUSED GWEN_GUI *gui,
+                                       const char *caption,
+                                       GWEN_GUI_FILENAME_TYPE fnt,
+                                       GWEN_UNUSED uint32_t flags,
+                                       GWEN_UNUSED const char *patterns,
+                                       GWEN_BUFFER *pathBuffer,
+                                       GWEN_UNUSED uint32_t guiid)
+{
   char *folder=NULL;
   char *fileName=NULL;
 
@@ -187,35 +198,35 @@ GWENHYWFAR_CB int GTK2_Gui_GetFileName(GWEN_GUI *gui,
     }
   }
 
-  switch(fnt) {
+  switch (fnt) {
   case GWEN_Gui_FileNameType_OpenFileName: {
     GtkWidget *dialog;
 
     if (!(caption && *caption))
       caption=I18N("Open File");
-    dialog=gtk_file_chooser_dialog_new (caption,
-					NULL,
-					GTK_FILE_CHOOSER_ACTION_OPEN,
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-					NULL);
+    dialog=gtk_file_chooser_dialog_new(caption,
+                                       NULL,
+                                       GTK_FILE_CHOOSER_ACTION_OPEN,
+                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                       NULL);
     if (folder && *folder)
-      gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER (dialog), folder);
+      gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), folder);
     if (fileName && *fileName)
       gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), fileName);
 
     if (gtk_dialog_run(GTK_DIALOG(dialog))==GTK_RESPONSE_ACCEPT) {
       char *filename;
 
-      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+      filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
       GWEN_Buffer_Reset(pathBuffer);
       GWEN_Buffer_AppendString(pathBuffer, filename);
-      g_free (filename);
-      gtk_widget_destroy (dialog);
+      g_free(filename);
+      gtk_widget_destroy(dialog);
       free(folder);
       return 0;
     }
-    gtk_widget_destroy (dialog);
+    gtk_widget_destroy(dialog);
     free(folder);
     return GWEN_ERROR_USER_ABORTED;
   }
@@ -225,22 +236,22 @@ GWENHYWFAR_CB int GTK2_Gui_GetFileName(GWEN_GUI *gui,
 
     if (!(caption && *caption))
       caption=I18N("Save File");
-    dialog=gtk_file_chooser_dialog_new (caption,
-					NULL,
-					GTK_FILE_CHOOSER_ACTION_SAVE,
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-					NULL);
-    gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
+    dialog=gtk_file_chooser_dialog_new(caption,
+                                       NULL,
+                                       GTK_FILE_CHOOSER_ACTION_SAVE,
+                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                       NULL);
+    gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(dialog), TRUE);
     if (folder && *folder)
-      gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER (dialog), folder);
+      gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), folder);
     if (fileName && *fileName)
       gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), fileName);
 
     if (gtk_dialog_run(GTK_DIALOG(dialog))==GTK_RESPONSE_ACCEPT) {
       char *filename;
 
-      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+      filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
       GWEN_Buffer_Reset(pathBuffer);
       GWEN_Buffer_AppendString(pathBuffer, filename);
       g_free(filename);
@@ -248,7 +259,7 @@ GWENHYWFAR_CB int GTK2_Gui_GetFileName(GWEN_GUI *gui,
       free(folder);
       return 0;
     }
-    gtk_widget_destroy (dialog);
+    gtk_widget_destroy(dialog);
     free(folder);
     return GWEN_ERROR_USER_ABORTED;
   }
@@ -258,24 +269,24 @@ GWENHYWFAR_CB int GTK2_Gui_GetFileName(GWEN_GUI *gui,
 
     if (!(caption && *caption))
       caption=I18N("Select Folder");
-    dialog=gtk_file_chooser_dialog_new (caption,
-					NULL,
-					GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-					NULL);
+    dialog=gtk_file_chooser_dialog_new(caption,
+                                       NULL,
+                                       GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                       NULL);
     if (gtk_dialog_run(GTK_DIALOG(dialog))==GTK_RESPONSE_ACCEPT) {
       char *filename;
 
-      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+      filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
       GWEN_Buffer_Reset(pathBuffer);
       GWEN_Buffer_AppendString(pathBuffer, filename);
-      g_free (filename);
-      gtk_widget_destroy (dialog);
+      g_free(filename);
+      gtk_widget_destroy(dialog);
       free(folder);
       return 0;
     }
-    gtk_widget_destroy (dialog);
+    gtk_widget_destroy(dialog);
     free(folder);
     return GWEN_ERROR_USER_ABORTED;
   }
