@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk2Gui_WHLayout_SetIntProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
+                                    GWEN_UNUSED int index,
                                     int value,
-                                    int doSignal) {
+                                    GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -47,14 +48,15 @@ int Gtk2Gui_WHLayout_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WHLayout_GetIntProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
-                                    int defaultValue) {
+                                    GWEN_UNUSED int index,
+                                    int defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -76,10 +78,11 @@ int Gtk2Gui_WHLayout_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WHLayout_SetCharProperty(GWEN_WIDGET *w,
-                                     GWEN_DIALOG_PROPERTY prop,
-                                     int index,
-                                     const char *value,
-                                     int doSignal) {
+                                     GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                     GWEN_UNUSED int index,
+                                     GWEN_UNUSED const char *value,
+                                     GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
@@ -94,10 +97,11 @@ int Gtk2Gui_WHLayout_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WHLayout_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WHLayout_GetCharProperty(GWEN_WIDGET *w,
+                                             GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                             GWEN_UNUSED int index,
+                                             const char *defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
@@ -112,7 +116,8 @@ const char* Gtk2Gui_WHLayout_GetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-int Gtk2Gui_WHLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
+int Gtk2Gui_WHLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild)
+{
   GtkWidget *g;
   GtkWidget *gChild;
   uint32_t cflags;
@@ -135,12 +140,13 @@ int Gtk2Gui_WHLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
 
 
 
-int Gtk2Gui_WHLayout_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WHLayout_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
-  uint32_t flags;
+  /*uint32_t flags;*/
   GWEN_WIDGET *wParent;
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   wParent=GWEN_Widget_Tree_GetParent(w);
 
 #if 0
@@ -153,8 +159,8 @@ int Gtk2Gui_WHLayout_Setup(GWEN_WIDGET *w) {
 #else
   g=gtk_hbox_new(FALSE, GTK2_GUI_DIALOG_DEFAULT_BOX_SPACING);
 #endif
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WHLayout_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WHLayout_GetIntProperty);
