@@ -50,7 +50,8 @@
 static GWEN_DB_NODE *gwen__paths=0;
 
 
-int GWEN_PathManager_ModuleInit(){
+int GWEN_PathManager_ModuleInit(void)
+{
   gwen__paths=GWEN_DB_Group_new("paths");
 
   return 0;
@@ -58,7 +59,8 @@ int GWEN_PathManager_ModuleInit(){
 
 
 
-int GWEN_PathManager_ModuleFini(){
+int GWEN_PathManager_ModuleFini(void)
+{
   GWEN_DB_Group_free(gwen__paths);
   gwen__paths=0;
   return 0;
@@ -67,7 +69,8 @@ int GWEN_PathManager_ModuleFini(){
 
 
 int GWEN_PathManager_DefinePath(const char *destLib,
-                                const char *pathName) {
+                                const char *pathName)
+{
   GWEN_DB_NODE *dbT;
 
   assert(destLib);
@@ -91,7 +94,8 @@ int GWEN_PathManager_DefinePath(const char *destLib,
 
 
 int GWEN_PathManager_UndefinePath(const char *destLib,
-                                  const char *pathName) {
+                                  const char *pathName)
+{
   GWEN_DB_NODE *dbT;
 
   assert(destLib);
@@ -117,7 +121,8 @@ int GWEN_PathManager_UndefinePath(const char *destLib,
 int GWEN_PathManager_AddPath(const char *callingLib,
                              const char *destLib,
                              const char *pathName,
-			     const char *pathValue) {
+                             const char *pathValue)
+{
   GWEN_DB_NODE *dbT;
   GWEN_BUFFER *buf;
 
@@ -146,8 +151,8 @@ int GWEN_PathManager_AddPath(const char *callingLib,
   GWEN_Directory_OsifyPath(pathValue, buf, 1);
 
   GWEN_DB_SetCharValue(dbT, GWEN_DB_FLAGS_DEFAULT,
-		       "path",
-		       GWEN_Buffer_GetStart(buf));
+                       "path",
+                       GWEN_Buffer_GetStart(buf));
   GWEN_Buffer_free(buf);
 
   return 0;
@@ -156,13 +161,14 @@ int GWEN_PathManager_AddPath(const char *callingLib,
 
 
 int GWEN_PathManager_AddRelPath(const char *callingLib,
-				const char *destLib,
-				const char *pathName,
-				const char *pathValue,
-				GWEN_PATHMANAGER_RELMODE rm) {
+                                const char *destLib,
+                                const char *pathName,
+                                const char *pathValue,
+                                GWEN_PATHMANAGER_RELMODE rm)
+{
   char cwd[256];
 
-  switch(rm) {
+  switch (rm) {
   case GWEN_PathManager_RelModeCwd: {
     const char *pcwd;
 
@@ -174,10 +180,10 @@ int GWEN_PathManager_AddRelPath(const char *callingLib,
       buf=GWEN_Buffer_new(0, 256, 0, 1);
       GWEN_Buffer_AppendString(buf, cwd);
       if (*pathValue!=GWEN_DIR_SEPARATOR)
-	GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
+        GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
       GWEN_Buffer_AppendString(buf, pathValue);
       rv=GWEN_PathManager_AddPath(callingLib, destLib, pathName,
-				  GWEN_Buffer_GetStart(buf));
+                                  GWEN_Buffer_GetStart(buf));
       GWEN_Buffer_free(buf);
       return rv;
     }
@@ -202,13 +208,13 @@ int GWEN_PathManager_AddRelPath(const char *callingLib,
       buf=GWEN_Buffer_new(0, 256, 0, 1);
       GWEN_Buffer_AppendString(buf, cwd);
       if (*pathValue!=GWEN_DIR_SEPARATOR)
-	GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
+        GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
       GWEN_Buffer_AppendString(buf, pathValue);
       DBG_INFO(GWEN_LOGDOMAIN,
-	       "Adding path [%s]",
-	       GWEN_Buffer_GetStart(buf));
+               "Adding path [%s]",
+               GWEN_Buffer_GetStart(buf));
       rv=GWEN_PathManager_AddPath(callingLib, destLib, pathName,
-				  GWEN_Buffer_GetStart(buf));
+                                  GWEN_Buffer_GetStart(buf));
       GWEN_Buffer_free(buf);
       return rv;
     }
@@ -221,8 +227,8 @@ int GWEN_PathManager_AddRelPath(const char *callingLib,
     rv=GWEN_Directory_GetHomeDirectory(cwd, sizeof(cwd)-1);
     if (rv) {
       DBG_ERROR(GWEN_LOGDOMAIN,
-		"Could not determine HOME directory (%d)",
-		rv);
+                "Could not determine HOME directory (%d)",
+                rv);
       return rv;
     }
     buf=GWEN_Buffer_new(0, 256, 0, 1);
@@ -231,7 +237,7 @@ int GWEN_PathManager_AddRelPath(const char *callingLib,
       GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
     GWEN_Buffer_AppendString(buf, pathValue);
     rv=GWEN_PathManager_AddPath(callingLib, destLib, pathName,
-				GWEN_Buffer_GetStart(buf));
+                                GWEN_Buffer_GetStart(buf));
     GWEN_Buffer_free(buf);
     return rv;
   }
@@ -248,7 +254,8 @@ int GWEN_PathManager_AddRelPath(const char *callingLib,
 int GWEN_PathManager_InsertPath(const char *callingLib,
                                 const char *destLib,
                                 const char *pathName,
-                                const char *pathValue) {
+                                const char *pathValue)
+{
   GWEN_DB_NODE *dbT;
 
   assert(destLib);
@@ -282,10 +289,101 @@ int GWEN_PathManager_InsertPath(const char *callingLib,
 
 
 
+int GWEN_PathManager_InsertRelPath(const char *callingLib,
+                                   const char *destLib,
+                                   const char *pathName,
+                                   const char *pathValue,
+                                   GWEN_PATHMANAGER_RELMODE rm)
+{
+  char cwd[256];
+
+  switch (rm) {
+  case GWEN_PathManager_RelModeCwd: {
+    const char *pcwd;
+
+    pcwd=getcwd(cwd, sizeof(cwd)-1);
+    if (pcwd) {
+      GWEN_BUFFER *buf;
+      int rv;
+
+      buf=GWEN_Buffer_new(0, 256, 0, 1);
+      GWEN_Buffer_AppendString(buf, cwd);
+      if (*pathValue!=GWEN_DIR_SEPARATOR)
+        GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
+      GWEN_Buffer_AppendString(buf, pathValue);
+      rv=GWEN_PathManager_InsertPath(callingLib, destLib, pathName,
+                                     GWEN_Buffer_GetStart(buf));
+      GWEN_Buffer_free(buf);
+      return rv;
+    }
+    else {
+      DBG_ERROR(GWEN_LOGDOMAIN, "getcwd(): %s", strerror(errno));
+      return GWEN_ERROR_IO;
+    }
+    break;
+  }
+
+  case GWEN_PathManager_RelModeExe: {
+    int rv;
+
+    rv=GWEN_Directory_GetPrefixDirectory(cwd, sizeof(cwd)-1);
+    if (rv) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+    else {
+      GWEN_BUFFER *buf;
+
+      buf=GWEN_Buffer_new(0, 256, 0, 1);
+      GWEN_Buffer_AppendString(buf, cwd);
+      if (*pathValue!=GWEN_DIR_SEPARATOR)
+        GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
+      GWEN_Buffer_AppendString(buf, pathValue);
+      DBG_INFO(GWEN_LOGDOMAIN,
+               "Adding path [%s]",
+               GWEN_Buffer_GetStart(buf));
+      rv=GWEN_PathManager_InsertPath(callingLib, destLib, pathName,
+                                     GWEN_Buffer_GetStart(buf));
+      GWEN_Buffer_free(buf);
+      return rv;
+    }
+  }
+
+  case GWEN_PathManager_RelModeHome: {
+    GWEN_BUFFER *buf;
+    int rv;
+
+    rv=GWEN_Directory_GetHomeDirectory(cwd, sizeof(cwd)-1);
+    if (rv) {
+      DBG_ERROR(GWEN_LOGDOMAIN,
+                "Could not determine HOME directory (%d)",
+                rv);
+      return rv;
+    }
+    buf=GWEN_Buffer_new(0, 256, 0, 1);
+    GWEN_Buffer_AppendString(buf, cwd);
+    if (*pathValue!=GWEN_DIR_SEPARATOR)
+      GWEN_Buffer_AppendString(buf, GWEN_DIR_SEPARATOR_S);
+    GWEN_Buffer_AppendString(buf, pathValue);
+    rv=GWEN_PathManager_InsertPath(callingLib, destLib, pathName,
+                                   GWEN_Buffer_GetStart(buf));
+    GWEN_Buffer_free(buf);
+    return rv;
+  }
+
+  default:
+    DBG_INFO(GWEN_LOGDOMAIN, "Unknown relative mode %d", rm);
+    return GWEN_ERROR_INVALID;
+  }
+}
+
+
+
 int GWEN_PathManager_RemovePath(const char *callingLib,
                                 const char *destLib,
                                 const char *pathName,
-                                const char *pathValue) {
+                                const char *pathValue)
+{
   GWEN_DB_NODE *dbT;
   const char *s;
   const char *p;
@@ -301,18 +399,18 @@ int GWEN_PathManager_RemovePath(const char *callingLib,
     return GWEN_ERROR_NOT_FOUND;
 
   dbT=GWEN_DB_FindFirstGroup(dbT, "pair");
-  while(dbT) {
+  while (dbT) {
     p=GWEN_DB_GetCharValue(dbT, "path", 0, 0);
     assert(p);
     s=GWEN_DB_GetCharValue(dbT, "lib", 0, 0);
 
     if (
-        (
-         (!callingLib && !s) ||
-         (callingLib && s && strcasecmp(s, callingLib)==0)
-        ) &&
-        strcasecmp(p, pathValue)==0
-       )
+      (
+        (!callingLib && !s) ||
+        (callingLib && s && strcasecmp(s, callingLib)==0)
+      ) &&
+      strcasecmp(p, pathValue)==0
+    )
       break;
     dbT=GWEN_DB_FindNextGroup(dbT, "pair");
   }
@@ -329,7 +427,8 @@ int GWEN_PathManager_RemovePath(const char *callingLib,
 
 
 
-int GWEN_PathManager_RemovePaths(const char *callingLib) {
+int GWEN_PathManager_RemovePaths(const char *callingLib)
+{
   GWEN_DB_NODE *dbT;
   const char *s;
 
@@ -337,15 +436,15 @@ int GWEN_PathManager_RemovePaths(const char *callingLib) {
   GWEN_DB_DeleteGroup(gwen__paths, callingLib);
 
   dbT=GWEN_DB_GetFirstGroup(gwen__paths);
-  while(dbT) {
+  while (dbT) {
     GWEN_DB_NODE *dbN;
 
     dbN=GWEN_DB_GetFirstGroup(dbT);
-    while(dbN) {
+    while (dbN) {
       GWEN_DB_NODE *dbNN;
 
       dbNN=GWEN_DB_FindFirstGroup(dbN, "pair");
-      while(dbNN) {
+      while (dbNN) {
         GWEN_DB_NODE *dbNext;
 
         dbNext=GWEN_DB_FindNextGroup(dbNN, "pair");
@@ -369,7 +468,8 @@ int GWEN_PathManager_RemovePaths(const char *callingLib) {
 
 
 int GWEN_PathManager_PathChanged(const char *destLib,
-                                 const char *pathName) {
+                                 const char *pathName)
+{
   GWEN_DB_NODE *dbT;
 
   assert(gwen__paths);
@@ -392,7 +492,8 @@ int GWEN_PathManager_PathChanged(const char *destLib,
 
 
 GWEN_STRINGLIST *GWEN_PathManager_GetPaths(const char *destLib,
-                                           const char *pathName) {
+                                           const char *pathName)
+{
   GWEN_DB_NODE *dbT;
 
   assert(gwen__paths);
@@ -411,7 +512,7 @@ GWEN_STRINGLIST *GWEN_PathManager_GetPaths(const char *destLib,
 
       /* then add all paths from other libs */
       dbN=GWEN_DB_FindFirstGroup(dbT, "pair");
-      while(dbN) {
+      while (dbN) {
         for (i=0; ; i++) {
           s=GWEN_DB_GetCharValue(dbN, "path", i, 0);
           if (!s)
@@ -438,9 +539,10 @@ GWEN_STRINGLIST *GWEN_PathManager_GetPaths(const char *destLib,
 
 
 int GWEN_PathManager_FindFile(const char *destLib,
-			      const char *pathName,
-			      const char *fileName,
-			      GWEN_BUFFER *fbuf) {
+                              const char *pathName,
+                              const char *fileName,
+                              GWEN_BUFFER *fbuf)
+{
   GWEN_DB_NODE *dbT;
 
   assert(gwen__paths);
@@ -459,35 +561,35 @@ int GWEN_PathManager_FindFile(const char *destLib,
 
       /* check all paths */
       dbN=GWEN_DB_FindFirstGroup(dbT, "pair");
-      while(dbN) {
+      while (dbN) {
         for (i=0; ; i++) {
           s=GWEN_DB_GetCharValue(dbN, "path", i, 0);
           if (!s)
-	    break;
-	  else {
-	    FILE *f;
-	
-	    GWEN_Buffer_AppendString(tbuf, s);
-	    GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
-	    GWEN_Buffer_AppendString(tbuf, fileName);
-	    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
-		      GWEN_Buffer_GetStart(tbuf));
-	    f=fopen(GWEN_Buffer_GetStart(tbuf), "r");
-	    if (f) {
-	      fclose(f);
-	      DBG_DEBUG(GWEN_LOGDOMAIN,
-			"File \"%s\" found in folder \"%s\"",
-			fileName,
-			s);
-	      GWEN_Buffer_AppendBuffer(fbuf, tbuf);
-	      GWEN_Buffer_free(tbuf);
-	      return 0;
-	    }
-	    GWEN_Buffer_Reset(tbuf);
-	  }
-	}
+            break;
+          else {
+            FILE *f;
 
-	dbN=GWEN_DB_FindNextGroup(dbN, "pair");
+            GWEN_Buffer_AppendString(tbuf, s);
+            GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+            GWEN_Buffer_AppendString(tbuf, fileName);
+            DBG_INFO(GWEN_LOGDOMAIN, "Trying \"%s\"",
+                      GWEN_Buffer_GetStart(tbuf));
+            f=fopen(GWEN_Buffer_GetStart(tbuf), "r");
+            if (f) {
+              fclose(f);
+              DBG_DEBUG(GWEN_LOGDOMAIN,
+                        "File \"%s\" found in folder \"%s\"",
+                        fileName,
+                        s);
+              GWEN_Buffer_AppendBuffer(fbuf, tbuf);
+              GWEN_Buffer_free(tbuf);
+              return 0;
+            }
+            GWEN_Buffer_Reset(tbuf);
+          }
+        }
+
+        dbN=GWEN_DB_FindNextGroup(dbN, "pair");
       }
       GWEN_Buffer_free(tbuf);
     }
@@ -500,10 +602,11 @@ int GWEN_PathManager_FindFile(const char *destLib,
 
 
 int GWEN_PathManager_GetMatchingFilesRecursively(const char *destLib,
-						 const char *pathName,
-						 const char *subFolderName,
-						 GWEN_STRINGLIST *sl,
-						 const char *mask) {
+                                                 const char *pathName,
+                                                 const char *subFolderName,
+                                                 GWEN_STRINGLIST *sl,
+                                                 const char *mask)
+{
   GWEN_DB_NODE *dbT;
 
   assert(gwen__paths);
@@ -522,26 +625,26 @@ int GWEN_PathManager_GetMatchingFilesRecursively(const char *destLib,
 
       /* check all paths */
       dbN=GWEN_DB_FindFirstGroup(dbT, "pair");
-      while(dbN) {
+      while (dbN) {
         for (i=0; ; i++) {
           s=GWEN_DB_GetCharValue(dbN, "path", i, 0);
           if (!s)
-	    break;
-	  else {
-	    GWEN_Buffer_AppendString(tbuf, s);
-	    if (subFolderName && *subFolderName) {
-	      GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
-	      GWEN_Buffer_AppendString(tbuf, subFolderName);
-	    }
+            break;
+          else {
+            GWEN_Buffer_AppendString(tbuf, s);
+            if (subFolderName && *subFolderName) {
+              GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+              GWEN_Buffer_AppendString(tbuf, subFolderName);
+            }
 
-	    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
-		      GWEN_Buffer_GetStart(tbuf));
-	    GWEN_Directory_GetMatchingFilesRecursively(GWEN_Buffer_GetStart(tbuf), sl, mask);
-	    GWEN_Buffer_Reset(tbuf);
-	  }
-	}
+            DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
+                      GWEN_Buffer_GetStart(tbuf));
+            GWEN_Directory_GetMatchingFilesRecursively(GWEN_Buffer_GetStart(tbuf), sl, mask);
+            GWEN_Buffer_Reset(tbuf);
+          }
+        }
 
-	dbN=GWEN_DB_FindNextGroup(dbN, "pair");
+        dbN=GWEN_DB_FindNextGroup(dbN, "pair");
       }
       GWEN_Buffer_free(tbuf);
     }
@@ -559,7 +662,8 @@ int GWEN_PathManager_AddPathFromWinReg(const char *callingLib,
                                        const char *destLib,
                                        const char *pathName,
                                        const char *keypath,
-                                       const char *varname){
+                                       const char *varname)
+{
   HKEY hkey;
   TCHAR nbuffer[MAX_PATH];
   BYTE vbuffer[MAX_PATH];
@@ -571,7 +675,7 @@ int GWEN_PathManager_AddPathFromWinReg(const char *callingLib,
   snprintf(nbuffer, sizeof(nbuffer), keypath);
 
   /* open the key */
-  if (RegOpenKey(HKEY_LOCAL_MACHINE, nbuffer, &hkey)){
+  if (RegOpenKey(HKEY_LOCAL_MACHINE, nbuffer, &hkey)) {
     DBG_INFO(GWEN_LOGDOMAIN, "RegOpenKey %s failed.", keypath);
     return 1;
   }
@@ -595,14 +699,14 @@ int GWEN_PathManager_AddPathFromWinReg(const char *callingLib,
       return GWEN_PathManager_AddPath(callingLib,
                                       destLib,
                                       pathName,
-                                      (char*)vbuffer);
+                                      (char *)vbuffer);
     }
   } /* for */
 
   RegCloseKey(hkey);
   DBG_INFO(GWEN_LOGDOMAIN,
-	   "In RegKey \"%s\" the variable \"%s\" does not exist",
-	   keypath, varname);
+           "In RegKey \"%s\" the variable \"%s\" does not exist",
+           keypath, varname);
   return 1;
 }
 
@@ -610,10 +714,11 @@ int GWEN_PathManager_AddPathFromWinReg(const char *callingLib,
 
 
 int GWEN_PathManager_AddPathFromWinReg(GWEN_UNUSED const char *callingLib,
-				       GWEN_UNUSED const char *destLib,
+                                       GWEN_UNUSED const char *destLib,
                                        GWEN_UNUSED const char *pathName,
                                        GWEN_UNUSED const char *keypath,
-				       GWEN_UNUSED const char *varname){
+                                       GWEN_UNUSED const char *varname)
+{
   return 0;
 }
 
