@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -62,6 +59,7 @@ extern "C" {
 
 /** @name Error Codes */
 /*@{*/
+/*@TODO: remove this */
 #define GWEN_SOCKET_ERROR_TYPE "Socket"
 #define GWEN_SOCKET_ERROR_BAD_SOCKETTYPE (-1)
 #define GWEN_SOCKET_ERROR_NOT_OPEN       (-2)
@@ -84,7 +82,8 @@ typedef enum {
   GWEN_SocketTypeRAW,
   GWEN_SocketTypeUnix,
   GWEN_SocketTypeFile
-} GWEN_SOCKETTYPE;
+}
+GWEN_SOCKETTYPE;
 
 
 
@@ -105,7 +104,7 @@ typedef enum {
  * @ref GWEN_Socket_Select.
  */
 /*@{*/
-GWENHYWFAR_API GWEN_SOCKETSET *GWEN_SocketSet_new();
+GWENHYWFAR_API GWEN_SOCKETSET *GWEN_SocketSet_new(void);
 GWENHYWFAR_API void GWEN_SocketSet_free(GWEN_SOCKETSET *ssp);
 GWENHYWFAR_API int GWEN_SocketSet_Clear(GWEN_SOCKETSET *ssp);
 /*@}*/
@@ -118,11 +117,11 @@ GWENHYWFAR_API int GWEN_SocketSet_Clear(GWEN_SOCKETSET *ssp);
  */
 /*@{*/
 GWENHYWFAR_API
-  int GWEN_SocketSet_AddSocket(GWEN_SOCKETSET *ssp,
-			       const GWEN_SOCKET *sp);
+int GWEN_SocketSet_AddSocket(GWEN_SOCKETSET *ssp,
+                             const GWEN_SOCKET *sp);
 GWENHYWFAR_API
-  int GWEN_SocketSet_RemoveSocket(GWEN_SOCKETSET *ssp,
-                                             const GWEN_SOCKET *sp);
+int GWEN_SocketSet_RemoveSocket(GWEN_SOCKETSET *ssp,
+                                const GWEN_SOCKET *sp);
 GWENHYWFAR_API int GWEN_SocketSet_HasSocket(GWEN_SOCKETSET *ssp,
                                             const GWEN_SOCKET *sp);
 GWENHYWFAR_API int GWEN_SocketSet_GetSocketCount(GWEN_SOCKETSET *ssp);
@@ -198,8 +197,8 @@ GWENHYWFAR_API int GWEN_Socket_Listen(GWEN_SOCKET *sp, int backlog);
  */
 GWENHYWFAR_API
 int GWEN_Socket_Accept(GWEN_SOCKET *sp,
-		       GWEN_INETADDRESS **addr,
-		       GWEN_SOCKET **newsock);
+                       GWEN_INETADDRESS **addr,
+                       GWEN_SOCKET **newsock);
 
 /*@}*/
 
@@ -226,8 +225,8 @@ GWENHYWFAR_API GWEN_SOCKETTYPE GWEN_Socket_GetSocketType(GWEN_SOCKET *sp);
  * peer. In that case the caller is responsible for freeing that address.
  */
 GWENHYWFAR_API
-  int GWEN_Socket_GetPeerAddr(GWEN_SOCKET *sp,
-                                         GWEN_INETADDRESS **addr);
+int GWEN_Socket_GetPeerAddr(GWEN_SOCKET *sp,
+                            GWEN_INETADDRESS **addr);
 
 /**
  * This function waits for a group of sockets to change their state.
@@ -238,10 +237,10 @@ GWENHYWFAR_API
  * will wait forever, if ==0 then it won't wait at all.
  */
 GWENHYWFAR_API
-  int GWEN_Socket_Select(GWEN_SOCKETSET *rs,
-			 GWEN_SOCKETSET *ws,
-			 GWEN_SOCKETSET *xs,
-			 int timeout);
+int GWEN_Socket_Select(GWEN_SOCKETSET *rs,
+                       GWEN_SOCKETSET *ws,
+                       GWEN_SOCKETSET *xs,
+                       int timeout);
 
 /**
  * Wait until the given socket becomes readable or a timeout occurrs.
@@ -249,7 +248,7 @@ GWENHYWFAR_API
  * @param timeout please see @ref GWEN_Socket_Select for details
  */
 GWENHYWFAR_API
-  int GWEN_Socket_WaitForRead(GWEN_SOCKET *sp, int timeout);
+int GWEN_Socket_WaitForRead(GWEN_SOCKET *sp, int timeout);
 
 /**
  * Wait until the given socket becomes writeable or a timeout occurrs.
@@ -257,7 +256,7 @@ GWENHYWFAR_API
  * @param timeout please see @ref GWEN_Socket_Select for details
  */
 GWENHYWFAR_API
-  int GWEN_Socket_WaitForWrite(GWEN_SOCKET *sp, int timeout);
+int GWEN_Socket_WaitForWrite(GWEN_SOCKET *sp, int timeout);
 /*@}*/
 
 /**
@@ -279,8 +278,8 @@ GWENHYWFAR_API
  * bytes actually read.
  */
 GWENHYWFAR_API int GWEN_Socket_Read(GWEN_SOCKET *sp,
-                                               char *buffer,
-                                               int *bsize);
+                                    char *buffer,
+                                    int *bsize);
 
 /**
  * Write bytes to an open socket.
@@ -291,8 +290,8 @@ GWENHYWFAR_API int GWEN_Socket_Read(GWEN_SOCKET *sp,
  * written. Please note that this function may write less bytes than expected!
  */
 GWENHYWFAR_API int GWEN_Socket_Write(GWEN_SOCKET *sp,
-				     const char *buffer,
-				     int *bsize);
+                                     const char *buffer,
+                                     int *bsize);
 
 /**
  * Reads bytes from an UDP socket, which is connectionless.
@@ -307,10 +306,10 @@ GWENHYWFAR_API int GWEN_Socket_Write(GWEN_SOCKET *sp,
  * bytes actually read.
  */
 GWENHYWFAR_API
-  int GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
-			   GWEN_INETADDRESS **addr,
-			   char *buffer,
-			   int *bsize);
+int GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
+                         GWEN_INETADDRESS **addr,
+                         char *buffer,
+                         int *bsize);
 /**
  * Writes data to an UDP socket, which is connectionless.
  * @param sp socket
@@ -321,10 +320,10 @@ GWENHYWFAR_API
  * written. Please note that this function may write less bytes than expected!
   */
 GWENHYWFAR_API
-  int GWEN_Socket_WriteTo(GWEN_SOCKET *sp,
-			  const GWEN_INETADDRESS *addr,
-			  const char *buffer,
-			  int *bsize);
+int GWEN_Socket_WriteTo(GWEN_SOCKET *sp,
+                        const GWEN_INETADDRESS *addr,
+                        const char *buffer,
+                        int *bsize);
 /*@}*/
 
 /**
@@ -368,14 +367,14 @@ GWENHYWFAR_API int GWEN_Socket_GetSocketError(GWEN_SOCKET *sp);
  * @param fl if nonzero then reusing the address is enabled
  */
 GWENHYWFAR_API
-  int GWEN_Socket_SetReuseAddress(GWEN_SOCKET *sp, int fl);
+int GWEN_Socket_SetReuseAddress(GWEN_SOCKET *sp, int fl);
 /*@}*/
 
 
 /**
  * This function should only be used if it is absolutely necessary,
  * because it might not be supported by every system.
- * Hoever, it is currently supported by all systems on which the
+ * However, it is currently supported by all systems on which the
  * Berkeley Socket API is used (e.g. most if not all POSIX systems,
  * in this implementation also WIN32).
  * What you can do with the value returned depends very much on the
